@@ -1,8 +1,6 @@
 #undef PACKAGE
 #undef VERSION
 #undef HAVE_LIBSM
-#undef GDM_CONFIG_FILE
-#undef GDM_XAUTH_PATH
 #undef ENABLE_NLS
 #undef HAVE_CATGETS
 #undef HAVE_GETTEXT
@@ -11,4 +9,5 @@
 #undef HAVE_PAM
 #undef HAVE_TCPWRAPPERS
 #undef HAVE_SHADOW
-
+#undef HAVE_CRYPT
+#undef HAVE_LIBXINERAMA
