@@ -30,7 +30,7 @@
 #include "misc.h"
 #include "xdmcp.h"
 
-static const gchar RCSid[]="$Id: display.c,v 1.8 2001/02/01 09:47:57 jirka Exp $";
+static const gchar RCSid[]="$Id: display.c,v 1.9 2001/02/04 00:38:43 jirka Exp $";
 
 /* External vars */
 extern gboolean GdmXdmcp;
@@ -190,6 +190,10 @@ gdm_display_manage (GdmDisplay *d)
 	break;
     }
 
+    if (d->type == TYPE_LOCAL) {
+	    d->dispstat = DISPLAY_SUCCESS;
+    }
+
     /* reset sleep to 0 */
     d->sleep_before_run = 0;
 
