@@ -42,7 +42,7 @@
 #include "gdm.h"
 #include "filecheck.h"
 
-static const gchar RCSid[]="$Id: gdmlogin.c,v 1.27 2001/02/03 02:36:38 jirka Exp $";
+static const gchar RCSid[]="$Id: gdmlogin.c,v 1.28 2001/02/03 22:55:59 jirka Exp $";
 
 static gboolean GdmBrowser;
 static gboolean GdmDebug;
@@ -1993,7 +1993,7 @@ gdm_screen_init (void)
 		if (screen_num <= 0) 
 			gdm_login_abort ("Xinerama active, but <= 0 screens?");
 
-		if (screen_num < GdmXineramaScreen)
+		if (screen_num <= GdmXineramaScreen)
 			GdmXineramaScreen = 0;
 
 		screen.x = screens[GdmXineramaScreen].x_org;
